# ``lwsspy.ml`` (Machine Learning)

Small library of functions I have worked with to 

|__Documentation__| __https://lwsspy.github.io/lwsspy.ml/__|
|-|-|
|__Deployment__  | __[![PyPi](https://img.shields.io/pypi/v/lwsspy.ml.svg?logo=python&logoColor=white)](https://pypi.org/project/meshslice/0.0.3/)__|
|__Build Status__| __[![Build Status](https://travis-ci.com/lwsspy/lwsspy.ml.svg?branch=main)](https://travis-ci.com/lwsspy/lwsspy.meshslice)__|
|__License__     |__[![License: GPL v3](https://img.shields.io/badge/License-GPLv3-blue.svg)](https://www.gnu.org/licenses/gpl-3.0)__|



## Quick-Install

```bash
pip install lwsspy.ml
```


## Quick-Usage

```python
from lwsspy.ml import VolumeLabeler, ImageLabeler
```





